; TETRIS.ASM v0.01
; ----------
;
; This is a work-in-progress for a 'Tetris' game for the PC-Engine,
; created using the MagicKit assembler.
;
; Key pieces of information:
;
;  playfield = 20 char's vertically
;              10 char's horizontally
;
;  pieces (see piece data near end of listing)
;
;

	.include "startup.asm"
	.mlist
	.list

;
;---- Constants used by program --------------------------------------
;

;
; ---- Globals: ------------
;
BGMAPHEIGHT	= 32		; 32 tiles high
BGMAPWIDTH	= 64		; 64 tiles wide (using 'virtual' mode)

FIELDWIDTH	= 10		; Field size - # tiles wide
FIELDHEIGHT	= 20		; (# tiles high)

FIELDX		= 20		; field x-position in tiles - top left corner
FIELDY		= 5		; (y-position)

FLD_SPRXORG	= (FIELDX*8+32)	; pixel-based origin x-position (for sprites)
FLD_SPRYORG	= (FIELDY*8+64)	; (y-position)

BAT_VRAMLOC	= $0000		; always starts at zero
CG_VRAMLOC	= $1000		; VRAM memory location for CG ('tile') data
SPR_VRAMLOC	= $5000		; VRAM memory location for sprite data
SATB_VRAMLOC	= $7F00		; VRAM memory location of SATB

;
; ---- Structure definition: ------------
; (use constants as offsets into struct):
;
;
; 'C' definition of piece-phase data structure:
;
; struct piecephasedata {
;	u_char		width;
;	u_char		height;
;	struct sqrpos	{
;		u_char	x;
;		u_char	y;
;       } square[4];
;	u_int16		sprite_pattern_vram_address;
;	char		sprite_x_rotate_adjustment;
;	char		sprite_y_rotate_adjustment;
; }

		.rsset	0	; start counting at 0
PHS_WIDTH	.rs	1
PHS_HEIGHT	.rs	1
PHS_SQR1X	.rs	1
PHS_SQR1Y	.rs	1
PHS_SQR2X	.rs	1
PHS_SQR2Y	.rs	1
PHS_SQR3X	.rs	1
PHS_SQR3Y	.rs	1
PHS_SQR4X	.rs	1
PHS_SQR4Y	.rs	1
PHS_PATADDR	.rs	2
PHS_ROTADJX	.rs	1
PHS_ROTADJY	.rs	1


;
;---- Zero Page area used by program ---------------------------------
;
		.zp

waitcnt:	.ds	1	; countdown (in VSYNC frames)

dspfldptr:	.ds	2	; pointer into display field


; sprite-specific .zp data:

pieceptr:	.ds	2	; pointer to piece data structure
phaseptr:	.ds	2	; pointer to piece phase data structure


; temporaries:

tmpptr:		.ds	2	; temporary field pointer
xcnt:		.ds	1	; temporary x counter
ycnt:		.ds	1	; temporary y counter
tmpzp:		.ds	1	; temporary variable


;
;---- Scratchpad RAM used by program ---------------------------------
;

		.bss

; sprite-specific .bss data:

ramsatb:	.ds	512	; RAM copy of sprite attribute table

pieceposx:	.ds	1	; x-position of piece (tile co-ordinates)
pieceposy:	.ds	1	; y-position of piece (tile co-ordinates)
piecenum:	.ds	1	; shape of piece
phasenum:	.ds	1	; rotated 'phase' of piece
sprpataddr:	.ds	2	; sprite pattern address
sx:		.ds	2	; sprite x-position
sy:		.ds	2	; sprite y-position

oldx:		.ds	1	; temp (used when testing move/rotate)
oldy:		.ds	1	; temp (used when testing move/rotate)
oldphs:		.ds	1	; temp (used when testing move/rotate)

tstx:		.ds	1	; test coordinates for individual blocks
tsty:		.ds	1
flg:		.ds	1	; return flag (0=ok, 1=err)

tmpcnt:		.ds	1	; counter


; dispfld is a field for display of items, 20 lines * 10 char's

dispfld:				; RAM copy of display field;
					; 1 square = 1 byte
displn00:	.ds	FIELDWIDTH	; (top line)
displn01:	.ds	FIELDWIDTH
displn02:	.ds	FIELDWIDTH
displn03:	.ds	FIELDWIDTH
displn04:	.ds	FIELDWIDTH
displn05:	.ds	FIELDWIDTH
displn06:	.ds	FIELDWIDTH
displn07:	.ds	FIELDWIDTH
displn08:	.ds	FIELDWIDTH
displn09:	.ds	FIELDWIDTH
displn10:	.ds	FIELDWIDTH
displn11:	.ds	FIELDWIDTH
displn12:	.ds	FIELDWIDTH
displn13:	.ds	FIELDWIDTH
displn14:	.ds	FIELDWIDTH
displn15:	.ds	FIELDWIDTH
displn16:	.ds	FIELDWIDTH
displn17:	.ds	FIELDWIDTH
displn18:	.ds	FIELDWIDTH
displn19:	.ds	FIELDWIDTH	; (bottom line)



;---[ STARTUP CODE ]------------------------------------------------------------

; initialize the interrupt vectors

		.code
		.bank	1
		.org	$C000

;---[ USER PROGRAM ]------------------------------------------------------------

main:

; Initialization section:
		jsr	loadvram	; load sprite/char/palettes into VRAM
		init_satb ramsatb	; init the RAM copy of SATB

; clear variables and arrays:

		jsr	clrdspfld	; init the playing field

; get ready for first display of screen:

		vsync			; synchronise with VSYNC interrupt

		jsr	dispbkgnd	; display (empty) background BAT map

		lda	#0		; initialize tetris piece info
					; to piece type #0
		sta	piecenum
		jsr	setpiece	; default piece values

		jsr	setsprvars	; calculate sprite values
		jsr	sprite2satb	; set values in (RAM version of) satb
		jsr	spritedisp	; update satb

; main processing/display loop:

.loop:		jsr	dispdspfld	; display the playing field

		vsync

		jsr	joypadmv	; move piece according to joypad input

		jsr	setsprvars	; update sprites on screen
		jsr	sprite2satb
		jsr	spritedisp

		bra	.loop		; repeat


;---[ USER SUBROUTINES ]--------------------------------------------------------

; ---- JOYSTICK routines ---------------------

;
; joypadmv - test joypad inputs, and move piece accordingly
;
; NOTE: 3 moves are possible in the same frame:
;       - rotate
;       - move horizontal
;       - move vertical
;
joypadmv:	lda	pieceposx	; store old position and phase
		sta	oldx		; in case move is not possible
		lda	pieceposy	; (restore old)
		sta	oldy
		lda	phasenum
		sta	oldphs

		lda	joytrg		; put joystick delta in zp
		sta	<tmpzp		; for easy branching

		bbs	#JOY_BITRUN,<tmpzp,xferplay	; xfer to playfield
		bbs	#JOY_BITSEL,<tmpzp,nxtpiece	; choose next piece type

		bbr	#JOY_BITI,  <tmpzp,.tstII
		jsr	rotclk		; rotate piece clockwise
		bra	.lftrt

.tstII:		bbr	#JOY_BITII, <tmpzp,.lftrt
		jsr	rotcntclk	; rotate piece counterclockwise

.lftrt:		lda	joytrg
		bbr	#JOY_BITLT, <tmpzp,.tstrt
		jsr	mvleft		; move piece left
		bra	.updn

.tstrt:		bbr	#JOY_BITRT, <tmpzp,.updn
		jsr	mvright		; move piece right

.updn:		lda	joytrg
		bbr	#JOY_BITUP, <tmpzp,.tstdn
		jsr	mvup
		bra	.ret

.tstdn:		bbr	#JOY_BITDN, <tmpzp,.ret
		jsr	mvdown		; move piece down

.ret:		rts


xferplay:	jsr	snapshot	; xfer to playfield
		jsr	nxtpiece
		rts

;
; nxtpiece - change to the next piece type
;
nxtpiece:	lda	piecenum
		inc	A
		cmp	#7		; only 0-6 types of pieces
		bne	.setpiece
		cla
.setpiece:	sta	piecenum
		jsr	setpiece
		rts

;
; setpiece - set default phase & position values for a piece
;
setpiece:	lda	piecenum
		cla
		sta	phasenum
		sta	pieceposx
		sta	pieceposy
		rts

;
; mvleft - move piece left
;
mvleft:		dec	pieceposx
		jsr	chkmvok
		lda	flg
		beq	.out
		jsr	backoutmv
.out:		rts

;
; mvright - move piece right
;
mvright:	inc	pieceposx
		jsr	chkmvok
		lda	flg
		beq	.out
		jsr	backoutmv
.out:		rts


;
; mvup - move piece up
;
mvup:		dec	pieceposy
		jsr	chkmvok
		lda	flg
		beq	.out
		jsr	backoutmv
.out:		rts

;
; mvdown - move piece down
;
mvdown:		inc	pieceposy
		jsr	chkmvok
		lda	flg
		beq	.out
		jsr	backoutmv
.out:		rts

;
; rotclk - rotate piece clockwise
;
rotclk:		lda	phasenum
		beq	.phase3
		dec	A
		bra	.adjust
.phase3:	lda	#3
.adjust:	sta	phasenum
		jsr	setphsptr	; new phase pointer

		ldy	#PHS_ROTADJX	; make rotate-adjustments to (x,y)
		lda	[phaseptr],Y
		add	pieceposx
		sta	pieceposx
		ldy	#PHS_ROTADJY
		lda	[phaseptr],Y
		add	pieceposy
		sta	pieceposy

		jsr	chkmvok
		lda	flg
		beq	.out
		jsr	backoutmv
.out:		rts

;
; rotcntclk - rotate piece counter-clockwise
;
rotcntclk:	lda	phasenum
		inc	A
		cmp	#4
		bne	.adjust
		cla
.adjust:	sta	phasenum
		jsr	setphsptr	; new phase pointer

		ldy	#PHS_ROTADJX	; make rotate-adjustments to (x,y)
		lda	[phaseptr],Y
		add	pieceposx
		sta	pieceposx
		ldy	#PHS_ROTADJY
		lda	[phaseptr],Y
		add	pieceposy
		sta	pieceposy

		jsr	chkmvok
		lda	flg
		beq	.out
		jsr	backoutmv
.out:		rts

;
; chkmvok - check updated phase/position to determine
;           whether it is valid
;
chkmvok:	stz	flg		; OK until proven otherwise

		ldy	#PHS_SQR1X	; test each square for validity
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	testsqr

		ldy	#PHS_SQR2X	; Tetris pieces all have 4 squares
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	testsqr

		ldy	#PHS_SQR3X
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	testsqr

		ldy	#PHS_SQR4X
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	testsqr
		rts

;
; testsqr - test a square for validity (for moving Tetris pieces)
;
testsqr:	lda	tstx		; test x range
		bmi	.bad		; < 0
		cmp	#FIELDWIDTH	; > maximum
		bcs	.bad

		lda	tsty		; test y range
		bmi	.bad		; < 0
		cmp	#FIELDHEIGHT	; > maximum
		bcs	.bad

		; Now find out if square is occupied:

		lda	tsty		; use tsty as index into displntbl
		asl	A		; array of pointers into the display
		tax			; field
		lda	displntbl,X
		sta	<dspfldptr
		inx
		lda	displntbl,X
		sta	<dspfldptr+1

		ldy	tstx		; now use 'tstx' as offset

		lda	[dspfldptr],Y	; if non-zero, it's occupied
		beq	.out
		
.bad:		lda	#1
		sta	flg

.out:		rts


;
; backoutmv - move was invalid; restore original position/phase
;
backoutmv:	lda	oldx		; move failed; restore original info
		sta	pieceposx
		lda	oldy
		sta	pieceposy
		lda	oldphs
		sta	phasenum
		rts

;
; snapshot - place piece into display field
;
snapshot:	ldy	#PHS_SQR1X	; move each square individually
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	setsqr

		ldy	#PHS_SQR2X	; Tetris pieces all have 4 squares
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	setsqr

		ldy	#PHS_SQR3X
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	setsqr

		ldy	#PHS_SQR4X
		lda	[phaseptr],Y
		add	pieceposx
		sta	tstx
		iny
		lda	[phaseptr],Y
		add	pieceposy
		sta	tsty
		jsr	setsqr

		rts

;
; setsqr - place a square into playfield (ie background)
;
setsqr:		lda	tsty		; use tsty as index into displntbl
		asl	A		; array of pointers into the display
		tax			; field
		lda	displntbl,X
		sta	<dspfldptr
		inx
		lda	displntbl,X
		sta	<dspfldptr+1

		ldy	tstx		; now use 'tstx' as offset

		lda	piecenum	; use piece type as marker
		inc	A

		sta	[dspfldptr],Y	; it's now occupied
		rts

; ---- SPRITE internals routines --------------------------

;
; setsprvars - setup sprite-related variables, based
;              on Tetris-piece information
;
setsprvars:	lda	pieceposx	; First, calculate sprite X-pos
		asl	A		; from tile co-ordinates
		asl	A
		asl 	A
		stz	sx+1
		sta	sx
		addw	#FLD_SPRXORG,sx

		lda	pieceposy	; Now calculate sprite Y-pos
		asl	A		; from tile co-ordinates
		asl	A
		asl	A
		stz	sy+1
		sta	sy
		addw	#FLD_SPRYORG,sy

setpcnphs:	lda	piecenum	; Find piece & phase pattern info
		asl	A		; First, get piece pointer
		stz	<tmpptr+1
		sta	<tmpptr
		addw	#piecetbl,<tmpptr
		cly
		lda	[tmpptr],Y
		sta	<pieceptr
		iny
		lda	[tmpptr],Y
		sta	<pieceptr+1

setphsptr:	lda	phasenum	; Next, get phase pointer
		asl	A
		tay
		lda	[pieceptr],Y
		sta	phaseptr
		iny
		lda	[pieceptr],Y
		sta	phaseptr+1

		ldy	#PHS_PATADDR
		lda	[phaseptr],Y
		sta	sprpataddr
		iny
		lda	[phaseptr],Y
		sta	sprpataddr+1

		rts

;
; sprite2satb - update sprite var's in (RAM version of) satb
;
sprite2satb:	spr_set		#0,ramsatb	; sprite #0 in ramsatb
		spr_x		sx
		spr_y		sy
		spr_pattern	sprpataddr
		spr_ctrl	#SIZE_MASK|FLIP_MASK,#SIZE_32x32|NO_FLIP
		spr_pri		#1		; foreground
		spr_pal		#0
		rts

;
; spritedisp - update the satb, to display sprite(s)
;
spritedisp:	update_satb	ramsatb
;,SATB_VRAMLOC
		rts


; ---- INITIALIZATION routines --------------------

;
; loadvram - load VRAM with sprite/character data
;            and associated palettes too
;

loadvram:	map	p0ph0cella	; map in temp graphics bank
		map	cgpal0		; map in temp graphics bank
		map	displntbl	; map in the data bank

		; load palette:

		set_bgpal	#0,cgpal0	; fill CG palette #0
		set_sprpal	#0,sprpal0	; fill Sprite palette #0

		; load characters into VRAM:

		vload	offchr,#5*16

		;
		; load sprites into VRAM at their respective locations
		;
		; NOTE: each sprite is 32x32; 2 'phases' exist in each
		; 32x64 sprite unit that it loaded into memory
		; (this macro loads sprites in 32x64 units)
		;

		load_sprites	VRAM(p0ph0cella),p0ph0cella,#2
		load_sprites	VRAM(p1ph0cella),p1ph0cella,#2
		load_sprites	VRAM(p2ph0cella),p2ph0cella,#2
		load_sprites	VRAM(p3ph0cella),p3ph0cella,#1
		load_sprites	VRAM(p4ph0cella),p4ph0cella,#1
		load_sprites	VRAM(p5ph0cella),p5ph0cella,#1
		load_sprites	VRAM(p6ph0cella),p6ph0cella,#1

		rts


; ---- MISCELLANEOUS routines -------------------

;
; wait_frames - Wait for a period of time (measured in VSYNC intervals)
;
; input - # of frames in waitcnt
;
wait_frames:	vsync

.l2:		dec	<waitcnt	; if processing took more than 1 frame,
		beq	.out
		dec	a		; then decrement correct # frames from
		bne	.l2		; waiting period (returned in reg 'A')

		lda	<waitcnt
		bne	wait_frames
.out:		rts



;
; display the background:
; (currently displays blank screen)
;

dispbkgnd:	setvwaddr #BAT_VRAMLOC	; set VRAM address to start of BAT map

		lda	#BGMAPHEIGHT	; # lines tall
.l1:		ldx	#BGMAPWIDTH	; # chars wide (whole virtual map)
		pha

.l2:		; store a blank character in each
		; BAT map location

		stw	#CHAR(offchr),video_data

		dex			; next char
		bne	.l2

		pla
		dec	a 		; next line
		bne	.l1

		rts

;
; clear the display field:
;

clrdspfld:	stw	#dispfld,<dspfldptr

		lda	#FIELDHEIGHT	; # tiles tall
.l1:		ldx	#FIELDWIDTH	; # chars wide
		pha
		cla
.l2:		sta	[dspfldptr]
		incw	<dspfldptr
		dex
		bne	.l2
		pla
		dec	a
		bne	.l1
		rts


;
; display the background, from the display field:
;

dispdspfld:	stw	#dispfld,<dspfldptr

		cla			; line #0 (FIELDHEIGHT lines total)

.l1:		pha
		asl	a		; use line# as index into table
		tax

		lda	dispvramtbl,x
		sta	<_di
		inx
		lda	dispvramtbl,x
		sta	<_di+1		; set the start VRAM address
		jsr	set_write	; for this line's BAT

		ldx	#FIELDWIDTH	; # chars wide

.l2:		lda	[dspfldptr]
		beq	.off

.on:		stw	#CHAR(fullchr),video_data
		bra	.next

.off:		stw	#CHAR(cornerchr),video_data

.next:		incw	<dspfldptr
		dex			; next block
		bne	.l2

		; finish the line with a 'right edge' character

		stw	#CHAR(endchr),video_data

		pla
		inc	a 		; next line
		cmp	#FIELDHEIGHT	; # lines total
		bne	.l1

		; now do trailing bottom edge:

		asl	a		; use line# as index into table
		tax

		lda	dispvramtbl,x
		sta	<_di
		inx
		lda	dispvramtbl,x
		sta	<_di+1		; set the start VRAM address
		jsr	set_write	; for this line's BAT

		ldx	#FIELDWIDTH	; # chars wide

.l3:		stw	#CHAR(bottomchr),video_data

		dex			; next block
		bne	.l3

		rts



;---[ GRAPHICS DATA ]-----------------------------------------------------------
;
; This data only needs to be mapped in order to load it
; into the video memory (then it can be unmapped)
;

	.data
	.bank	2
	.org	$4000

;---[ SPRITE DATA ]----------------------
;
; Piece 0 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      XX    X      X    XXX
;                  X     XXX    X      X
;                  X           XX
;
; cell data is 16x16, and each sprite is 32x32.
; cells are arranged as: A B
;                        C D
;
p0ph0cella:	.vram	SPR_VRAMLOC
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p0ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p0ph0cellc:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p0ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p0ph1cella:	.vram	SPR_VRAMLOC+$100
		.pal	0
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p0ph1cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p0ph1cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p0ph1celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p0ph2cella:	.vram	SPR_VRAMLOC+$200
		.pal	0
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
p0ph2cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p0ph2cellc:	dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p0ph2celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p0ph3cella:	.vram	SPR_VRAMLOC+$300
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p0ph3cellb:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p0ph3cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p0ph3celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

;
; Piece 1 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      XX    XXX   X       X
;                   X    X     X     XXX
;                   X          XX
;
p1ph0cella:	.vram	SPR_VRAMLOC+$400
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
p1ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p1ph0cellc:	dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p1ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p1ph1cella:	.vram	SPR_VRAMLOC+$500
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p1ph1cellb:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p1ph1cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p1ph1celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p1ph2cella:	.vram	SPR_VRAMLOC+$600
		.pal	0
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p1ph2cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p1ph2cellc:	dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p1ph2celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p1ph3cella:	.vram	SPR_VRAMLOC+$700
		.pal	0
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p1ph3cellb:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p1ph3cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p1ph3celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

;
; Piece 2 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      X      X     X    XXX
;                  XX    XXX   XX     X
;                  X            X
;
p2ph0cella:	.vram	SPR_VRAMLOC+$800
		.pal	0
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p2ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p2ph0cellc:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p2ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p2ph1cella:	.vram	SPR_VRAMLOC+$900
		.pal	0
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p2ph1cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p2ph1cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p2ph1celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p2ph2cella:	.vram	SPR_VRAMLOC+$A00
		.pal	0
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p2ph2cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p2ph2cellc:	dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p2ph2celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p2ph3cella:	.vram	SPR_VRAMLOC+$B00
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
p2ph3cellb:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p2ph3cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p2ph3celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

;
; Piece 3 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      X     XXXX  X    XXXX
;                  X           X
;                  X           X
;                  X           X
;
; Note: it rotates around the second square, not the first one
;
p3ph0cella:	.vram	SPR_VRAMLOC+$C00
		.pal	0
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p3ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p3ph0cellc:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p3ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p3ph1cella:	.vram	SPR_VRAMLOC+$D00
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p3ph1cellb:	dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p3ph1cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p3ph1celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

;
; Piece 4 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:       X    XX     X    XX
;                  XX     XX   XX     XX
;                  X           X 
;
p4ph0cella:	.vram	SPR_VRAMLOC+$E00
		.pal	0
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p4ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p4ph0cellc:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p4ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p4ph1cella:	.vram	SPR_VRAMLOC+$F00
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
p4ph1cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
p4ph1cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p4ph1celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

; ----------- End of Bank #2 (full) -----------

; ----------- Start of Bank #3 -----------
;
; This data only needs to be mapped in order to load it
; into the video memory (then it can be unmapped)
;

	.data
	.bank	3
	.org	$6000

;
; Piece 5 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      X      XX   X      XX
;                  XX    XX    XX    XX
;                   X           X
;
p5ph0cella:	.vram	SPR_VRAMLOC+$1000
		.pal	0
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p5ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p5ph0cellc:	dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p5ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

p5ph1cella:	.vram	SPR_VRAMLOC+$1100
		.pal	0
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF,$00FF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p5ph1cellb:	dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00,$FF00
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p5ph1cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p5ph1celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

;
; Piece 6 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      XX    XX    XX    XX
;                  XX    XX    XX    XX
;                                
p6ph0cella:	.vram	SPR_VRAMLOC+$1200
		.pal	0
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
		dw	$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF,$FFFF
p6ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p6ph0cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p6ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

;
; Piece 7 is just a placeholder, so that Piece 6 can be manipulated
;   by using the sprite MACROs (which use sprites 2x4-cells large)
;
;                                
p7ph0cella:	.vram	SPR_VRAMLOC+$1300
		.pal	0
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p7ph0cellb:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p7ph0cellc:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
p7ph0celld:	dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
		dw	$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000


;---[ PALETTE DATA ]---------------------
;
; Single palette entry
; (CG Palette and Sprite Palette are same)
;
; entry #0 = black, #1 = light gray, #2-#15 are bluish-green
;
cgpal0:		.defpal	$000,$222,$175,$175,$175,$175,$175,$175,\
			$175,$175,$175,$175,$175,$175,$175,$175
;
; entry #0 = black, #1 = light gray, #2-#15 are greenish-blue
;
sprpal0:	.defpal	$000,$222,$157,$157,$157,$157,$157,$157,\
			$157,$157,$157,$157,$157,$157,$157,$157


;---[ CHARACTER DATA ]-------------------
;
;  offchr    cornerchr   endchr    bottomchr  fullchr
;  $1000      $1010      $1020      $1030      $1040
; ........   XXXXXXXX   X.......   XXXXXXXX   XXXXXXXX
; ........   X.......   X.......   ........   XXXXXXXX
; ........   X.......   X.......   ........   XXXXXXXX
; ........   X.......   X.......   ........   XXXXXXXX
; ........   X.......   X.......   ........   XXXXXXXX
; ........   X.......   X.......   ........   XXXXXXXX
; ........   X.......   X.......   ........   XXXXXXXX
; ........   X.......   X.......   ........   XXXXXXXX
;
offchr:		.defchr	CG_VRAMLOC,0,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000

cornerchr:	defchr	CG_VRAMLOC+$10,0,\
			$11111111,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000

endchr:		defchr	CG_VRAMLOC+$20,0,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000,\
			$10000000

bottomchr:	defchr	CG_VRAMLOC+$30,0,\
			$11111111,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000,\
			$00000000

fullchr:	defchr	CG_VRAMLOC+$40,0,\
			$22222222,\
			$22222222,\
			$22222222,\
			$22222222,\
			$22222222,\
			$22222222,\
			$22222222,\
			$22222222


;---[ USER DATA ]---------------------------------------------------------------
;
; This data is needed on a fairly consistent basis while the
; Tetris mainloop is executing, so keep it mapped
;

	.data
	.bank	4
	.org	$8000

;
; Pointers to display field data, at the start of each line:
;
displntbl:	dw	displn00
		dw	displn01
		dw	displn02
		dw	displn03
		dw	displn04
		dw	displn05
		dw	displn06
		dw	displn07
		dw	displn08
		dw	displn09
		dw	displn10
		dw	displn11
		dw	displn12
		dw	displn13
		dw	displn14
		dw	displn15
		dw	displn16
		dw	displn17
		dw	displn18
		dw	displn19

;
; Pointers to display field VRAM addresses, at the start of each line:
;
dispvramorg	=	(FIELDY*BGMAPWIDTH)+FIELDX ; field's display location
dispvramtbl:	dw	dispvramorg
		dw	dispvramorg+( 1*BGMAPWIDTH)
		dw	dispvramorg+( 2*BGMAPWIDTH)
		dw	dispvramorg+( 3*BGMAPWIDTH)
		dw	dispvramorg+( 4*BGMAPWIDTH)
		dw	dispvramorg+( 5*BGMAPWIDTH)
		dw	dispvramorg+( 6*BGMAPWIDTH)
		dw	dispvramorg+( 7*BGMAPWIDTH)
		dw	dispvramorg+( 8*BGMAPWIDTH)
		dw	dispvramorg+( 9*BGMAPWIDTH)
		dw	dispvramorg+(10*BGMAPWIDTH)
		dw	dispvramorg+(11*BGMAPWIDTH)
		dw	dispvramorg+(12*BGMAPWIDTH)
		dw	dispvramorg+(13*BGMAPWIDTH)
		dw	dispvramorg+(14*BGMAPWIDTH)
		dw	dispvramorg+(15*BGMAPWIDTH)
		dw	dispvramorg+(16*BGMAPWIDTH)
		dw	dispvramorg+(17*BGMAPWIDTH)
		dw	dispvramorg+(18*BGMAPWIDTH)
		dw	dispvramorg+(19*BGMAPWIDTH)	; last line
		dw	dispvramorg+(20*BGMAPWIDTH)	; bottom edge

;
; General info about Tetris pieces' data
; --------------------------------------
;
; There are 7 different pieces in use, and each piece has
; up to 4 different rotations, or 'phases'.  Each piece has
; 4 sub-pieces, or 'squares', and each piece can be
; represented inside of a 2x2 cell sprite unit (32x32 pixels)
; Only piece #2 (the 4-unit long one) requires special
; consideration for its origin to be moved during a rotate
; operation.
;
;
; The overall data format is as follows:
; piece table(piece_index) -> phase table
; phase table(phase_index) -> phase data structure
;
; The data structure contains the following information:
; (listed in 'C' structure format)
;
; struct sqrpos {
;	u_char		x;
;	u_char		y;
; }
;
; struct piecephasedata {
;	u_char		width;
;	u_char		height;
;	struct sqrpos	square[4];
;	u_int16		sprite_pattern_vram_address;
;	char		sprite_x_rotate_adjustment;
;	char		sprite_y_rotate_adjustment;
; }
;
; the square data is used for detecting existing filled-blocks
; (for collision-detection), and for sprite-to-block transfer
; when the piece comes to rest
;
; sprite_x_rotate_adjustment (and y) is only used for piece #2, to
; compensate for its special rotation (around its second square)
;

;
; Tetris pieces' data
; -------------------
;
; piece #:         0     1     2     3     4     5     6
;
; appearance:      XX    XX    X     X      X    X     XX
;                  X      X    XX    X     XX    XX    XX
;                  X      X    X     X     X      X
;                                    X
;
piecetbl:	dw	p0phstbl
		dw	p1phstbl
		dw	p2phstbl
		dw	p3phstbl
		dw	p4phstbl
		dw	p5phstbl
		dw	p6phstbl


;
; Piece 0 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      XX    X      X    XXX
;                  X     XXX    X      X
;                  X           XX
;
p0phstbl:	dw	p0ph0dat
		dw	p0ph1dat
		dw	p0ph2dat
		dw	p0ph3dat

;
; Piece 1 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      XX    XXX   X       X
;                   X    X     X     XXX
;                   X          XX
;
p1phstbl:	dw	p1ph0dat
		dw	p1ph1dat
		dw	p1ph2dat
		dw	p1ph3dat

;
; Piece 2 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      X      X     X    XXX
;                  XX    XXX   XX     X
;                  X            X
;
p2phstbl:	dw	p2ph0dat
		dw	p2ph1dat
		dw	p2ph2dat
		dw	p2ph3dat

;
; Piece 3 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      X     XXXX  X    XXXX
;                  X           X
;                  X           X
;                  X           X
;
; Note: it rotates around the second square, not the first one
;
p3phstbl:	dw	p3ph0dat
		dw	p3ph1dat
		dw	p3ph0dat
		dw	p3ph1dat

;
; Piece 4 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:       X    XX     X    XX
;                  XX     XX   XX     XX
;                  X           X 
;
p4phstbl:	dw	p4ph0dat
		dw	p4ph1dat
		dw	p4ph0dat
		dw	p4ph1dat

;
; Piece 5 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      X      XX   X      XX
;                  XX    XX    XX    XX
;                   X           X
;
p5phstbl:	dw	p5ph0dat
		dw	p5ph1dat
		dw	p5ph0dat
		dw	p5ph1dat

;
; Piece 6 has the following rotation cycle: (counter-clockwise)
;
; phase #:         0     1     2     3
;
; appearance:      XX    XX    XX    XX
;                  XX    XX    XX    XX
;                                
;
p6phstbl:	dw	p6ph0dat
		dw	p6ph0dat
		dw	p6ph0dat
		dw	p6ph0dat


p0ph0dat:	db	2,3			; width, height
		db	0,0, 1,0, 0,1, 0,2	; 4 squares
		dw	SPR_VRAM(p0ph0cella)	; pattern address
		db	0,0			; x-,y-adjust

p0ph1dat:	db	3,2			; width, height
		db	0,0, 0,1, 1,1, 2,1	; 4 squares
		dw	SPR_VRAM(p0ph1cella)	; pattern address
		db	0,0			; x-,y-adjust

p0ph2dat:	db	2,3			; width, height
		db	1,0, 1,1, 1,2, 0,2	; 4 squares
		dw	SPR_VRAM(p0ph2cella)	; pattern address
		db	0,0			; x-,y-adjust

p0ph3dat:	db	3,2			; width, height
		db	0,0, 1,0, 2,0, 2,1	; 4 squares
		dw	SPR_VRAM(p0ph3cella)	; pattern address
		db	0,0			; x-,y-adjust


p1ph0dat:	db	2,3			; width, height
		db	0,0, 1,0, 1,1, 1,2	; 4 squares
		dw	SPR_VRAM(p1ph0cella)	; pattern address
		db	0,0			; x-,y-adjust

p1ph1dat:	db	3,2			; width, height
		db	0,0, 0,1, 1,0, 2,0	; 4 squares
		dw	SPR_VRAM(p1ph1cella)	; pattern address
		db	0,0			; x-,y-adjust

p1ph2dat:	db	2,3			; width, height
		db	0,0, 0,1, 0,2, 1,2	; 4 squares
		dw	SPR_VRAM(p1ph2cella)	; pattern address
		db	0,0			; x-,y-adjust

p1ph3dat:	db	3,2			; width, height
		db	0,1, 1,1, 2,1, 2,0	; 4 squares
		dw	SPR_VRAM(p1ph3cella)	; pattern address
		db	0,0			; x-,y-adjust


p2ph0dat:	db	2,3			; width, height
		db	0,0, 0,1, 1,1, 0,2	; 4 squares
		dw	SPR_VRAM(p2ph0cella)	; pattern address
		db	0,0			; x-,y-adjust

p2ph1dat:	db	3,2			; width, height
		db	0,1, 1,0, 1,1, 2,1	; 4 squares
		dw	SPR_VRAM(p2ph1cella)	; pattern address
		db	0,0			; x-,y-adjust

p2ph2dat:	db	2,3			; width, height
		db	0,1, 1,0, 1,1, 1,2	; 4 squares
		dw	SPR_VRAM(p2ph2cella)	; pattern address
		db	0,0			; x-,y-adjust

p2ph3dat:	db	3,2			; width, height
		db	0,0, 1,0, 2,0, 1,1	; 4 squares
		dw	SPR_VRAM(p2ph3cella)	; pattern address
		db	0,0			; x-,y-adjust


p3ph0dat:	db	1,4			; width, height
		db	0,0, 0,1, 0,2, 0,3	; 4 squares
		dw	SPR_VRAM(p3ph0cella)	; pattern address
		db	1,-1			; x-,y-adjust

p3ph1dat:	db	4,1			; width, height
		db	0,0, 1,0, 2,0, 3,0	; 4 squares
		dw	SPR_VRAM(p3ph1cella)	; pattern address
		db	-1,1			; x-,y-adjust


p4ph0dat:	db	2,3			; width, height
		db	1,0, 1,1, 0,1, 0,2	; 4 squares
		dw	SPR_VRAM(p4ph0cella)	; pattern address
		db	0,0			; x-,y-adjust

p4ph1dat:	db	3,2			; width, height
		db	0,0, 0,1, 1,1, 2,1	; 4 squares
		dw	SPR_VRAM(p4ph1cella)	; pattern address
		db	0,0			; x-,y-adjust


p5ph0dat:	db	2,3			; width, height
		db	0,0, 0,1, 1,1, 1,2	; 4 squares
		dw	SPR_VRAM(p5ph0cella)	; pattern address
		db	0,0			; x-,y-adjust

p5ph1dat:	db	3,2			; width, height
		db	0,1, 1,1, 1,0, 2,0	; 4 squares
		dw	SPR_VRAM(p5ph1cella)	; pattern address
		db	0,0			; x-,y-adjust


p6ph0dat:	db	2,2			; width, height
		db	0,0, 0,1, 1,0, 1,1	; 4 squares
		dw	SPR_VRAM(p6ph0cella)	; pattern address
		db	0,0			; x-,y-adjust


